# Scanorma for CytoTRACE (ScanoramaCT)

`scanoramaCT.py` is an adapted version of the original <a href="https://github.com/brianhie/scanorama">Scanorama code</a> for application to CytoTRACE. The code has been modified to adjust the aligned gene count vectors using Gaussian kernel normalization. CytoTRACE is then applied to the Scanorama-adjusted gene counts and expression matrix. 

`scanoramaCT` is now available within the CytoTRACE codebase and web framework (<a href="https://github.com/gunsagargulati/CytoTRACE">CytoTRACE GitHub</a>). 
